@@ -40,12 +40,12 @@ L<Devel::Ladybug::Constants>.
 
 =item * C<connect(%args)>
 
-Constructor for a MySQL GlobalDBI object.
+Constructor for a MySQL DBI object.
 
 C<%args> is a hash with keys for C<database> (database name), C<host>,
 C<port>, C<user>, and C<pass>.
 
-Returns a new L<GlobalDBI> instance.
+Returns a new L<DBI> instance.
 
 =back
 
@@ -54,31 +54,25 @@ Returns a new L<GlobalDBI> instance.
 use strict;
 use warnings;
 
-use Error qw| :try |;
 use Devel::Ladybug::Enum::Bool;
+use Error qw| :try |;
 
 use base qw| Devel::Ladybug::Persistence::Generic |;
 
-use constant RefOpts =>
-  [ "CASCADE", "SET NULL", "RESTRICT", "NO ACTION" ];
-
 sub connect {
   my %args = @_;
 
   my $dsn = sprintf( 'DBI:mysql:database=%s;host=%s;port=%s',
     $args{database}, $args{host}, $args{port} );
 
-  $GlobalDBI::CONNECTION{ $args{database} } ||=
-    [ $dsn, $args{user}, $args{pass}, { RaiseError => 1 } ];
-
-  return GlobalDBI->new( dbname => $args{database} );
+  return DBI->connect( $dsn, $args{user}, $args{pass}, { RaiseError => 1 } );
 }
 
 =pod
 
 =head1 SEE ALSO
 
-L<GlobalDBI>, L<DBI>, L<DBD::mysql>
+L<DBI>, L<DBD::mysql>
 
 L<Devel::Ladybug::Persistence>
 
@@ -370,7 +364,7 @@ sub __wrapWithReconnect {
   return $return;
 }
 
-sub __init {
+sub __INIT {
   my $class = shift;
 
   if ( $class =~ /::Abstract/ ) {
